@@ -10,9 +10,23 @@ import markdown
 import codecs
 import os
 
+import threading
+lock = threading.Lock()
+
+
+class Singleton(type):
+    _instances = {}
+
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            with lock:
+                if cls not in cls._instances:
+                    cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+        return cls._instances[cls]
+
 
 # Inspired from: https://chriswarrick.com/blog/2014/09/15/python-apps-the-right-way-entry_points-and-scripts/
-class Docs(object):
+class Docs(object, metaclass=Singleton):
     def __init__(self):
         self.__lang = None
         self.__charset = None
