@@ -2,8 +2,9 @@ import argparse
 import os
 from GLXDocs import Docs
 
-__authors__ = ["Tuxa", "Alias la Tuxette"]
+__authors__ = ["Tuxa"]
 __date__ = 20200325
+__version__ = 0.3
 __description__ = "Galaxie Docs"
 
 
@@ -11,21 +12,20 @@ def md2html():
     docs = Docs()
     parser = argparse.ArgumentParser(
         description=__description__,
-        epilog="Developed by {} on {}".format(
-            ", ".join(__authors__), __date__)
+        epilog="Developed by Galaxie under GPLv3+ license"
     )
-    parser.add_argument("source", help="Source file")
-    parser.add_argument("dest", help="Destination directory or file")
+    parser.add_argument("source", help="source file path")
+    parser.add_argument("destination", help="destination file path")
     parser.add_argument('--lang',
                         dest='lang',
                         default='en',
-                        help="set HTTP_ACCEPT_LANGUAGE"
+                        help="HTTP_ACCEPT_LANGUAGE"
                         )
 
     parser.add_argument('--charset',
                         dest='charset',
                         default='utf-8',
-                        help="set Character Sets"
+                        help="character sets"
                         )
     args = parser.parse_args()
     docs.lang = args.lang
